/*
 * C
 *
 * Copyright 2013 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

#include "cpu.h"
#if MCU == 2
#include "stm32f2xx.h"
#include "stm32f2xx_gpio.h"
#include "stm32f2xx_rcc.h"
#include "stm322xg_eval.h"
#elif MCU == 4
#include "stm32f4xx.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"
#include "stm324xg_eval.h"
#else
#error Invalid MCU
#endif

#define INVALID_ID	-1
#define OK	0

#define LED_COUNT 4

#define TEST_ID_OK if (id >=  LED_COUNT) return INVALID_ID ;

const uint16_t GPIO_ID[LED_COUNT] = { GPIO_Pin_6, GPIO_Pin_8, GPIO_Pin_9, GPIO_Pin_7};
const GPIO_TypeDef* GPIO_PORT_ID[LED_COUNT] = { GPIOG, GPIOG, GPIOI, GPIOC};
const uint32_t GPIO_CLOCK_PORT_ID[LED_COUNT] = { RCC_AHB1Periph_GPIOG, RCC_AHB1Periph_GPIOG, RCC_AHB1Periph_GPIOI, RCC_AHB1Periph_GPIOC};

/**
  * @brief  To initialize the LEDs in output PushPull.
  * @param  None
  * @retval None
  */
void LEDs_initLEDs(void) {
    int i ;
	GPIO_InitTypeDef GPIO_InitStructure;

	for(i = 0; i<LED_COUNT; i++)
	{
		/* Enable the BUTTON Clock */
		RCC_AHB1PeriphClockCmd(GPIO_CLOCK_PORT_ID[i], ENABLE);

		/* Configure Button pin as input */
		GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
		GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
		GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
		GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
		GPIO_InitStructure.GPIO_Pin = GPIO_ID[i];

		GPIO_Init((GPIO_TypeDef*)GPIO_PORT_ID[i], &GPIO_InitStructure);
	}
}

/**
  * @brief  To return the number of LEDs available
  * @param  None
  * @retval Output available
  */
int LEDs_getLEDsCount(void) {
 return LED_COUNT;
}

/**
  * @brief  To toggle output
  * @param  Output ID
  * @retval OK or invalid ID
  */
int LEDs_toggleLED(int id) {
 TEST_ID_OK;
 GPIO_ToggleBits((GPIO_TypeDef*)GPIO_PORT_ID[id], GPIO_ID[id]);
 return OK;
}
