/*
 * C
 *
 * Copyright 2013 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
#include <stdio.h>
#include "LLMJVM.h"
#include "sni.h"
#include "sram_driver.h"

#include "cpu.h"
#if MCU == 2
#include "stm32f2xx.h"
#include "stm322xg_eval.h"
#elif MCU == 4
#include "stm32f4xx.h"
#include "stm324xg_eval.h"
#else
#error Invalid MCU
#endif

#include "leds.h"
#include "config_tasks.h"

#define USE_JAVA_VERSION
#ifndef USE_JAVA_VERSION
/**
 * The original C program.
 * It schedules tasks inside a infinite loop.
 * Tasks are binded to 'real functions' in the file "config_tasks.h".
 */

int main(void)
{
    SRAM_initialize();
    LEDs_initLEDs();
    
    printf("START\n");
    
    while(1)
    {
        TASK_1;
        TASK_2;
        TASK_3;
        TASK_4;
        TASK_5;
    }  
//    return 0; // unreachable code
}

#else
/**
 * The Java program that ports the scheduler.
 *
 * The C code of the tasks is reused and accessed through native Java methods.
 * The implementation of these native methods just calls the tasks
 * the same way as does the original C scheduler (see above).
 * Hence, the "config_tasks.h" file can still be used.
 *
 * The main C program now initializes and starts the virtual machine.
 * The Java application will perform the infinite loop.
 *
 * In the end, porting is just changing the main function and implementing the native methods.
 */

// Global variables
void* vm;

// Main program
int main(void)
{
    // Variables
    int32_t err;
    int32_t exitcode;
    
    // Code
	printf("START\n");
 	
	SRAM_initialize();
    LEDs_initLEDs();
    
	vm = SNI_createVM();
	
	if(vm == NULL)
    {
		printf("VM initialization error.\n");
	}
	else
    {
        printf("VM START\n");
        err = SNI_startVM(vm, 0, NULL);
        
        if(err < 0){
            //Error occurred
            if(err == LLMJVM_E_EVAL_LIMIT)
            {
                printf("Evaluation limits reached.\n");
            }
            else
            {
                printf("VM execution error (err = %d).\n", err);
            }
        }
        else
        {
            //VM execution ends normally
            exitcode = SNI_getExitCode(vm);
            printf("VM END (exit code = %d)\n", exitcode);
        }
	}
	
	SNI_destroyVM(vm);
    
	printf("END\n");
}
#endif

// Implementation of native functions used in Java code
// Used only in the Java version 
// --> excluded from the #ifndef #else #endif control structure to avoid link edition issues
void Java_com_is2t_examples_Scheduler_Task1(void)
{
    TASK_1;
}

void Java_com_is2t_examples_Scheduler_Task2(void)
{
    TASK_2;
}

void Java_com_is2t_examples_Scheduler_Task3(void)
{
    TASK_3;
}

void Java_com_is2t_examples_Scheduler_Task4(void)
{
    TASK_4;
}

void Java_com_is2t_examples_Scheduler_Task5(void)
{
    TASK_5;
}
